/*  
 *  LPT Manager
 *  Copyright (C) 2002  Giovanni Pardini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include "aboutDlg.h"

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>
#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "lptmanager.h"
#include "support.h"
#include "options.h"
#include "functions.h"
#include "icon.h"


void showAboutDlg(void)
{
	GtkWidget *aboutDlg;
	
	aboutDlg = create_aboutDlg();
	gtk_window_set_transient_for(GTK_WINDOW(aboutDlg), GTK_WINDOW(publicVars.mainWnd));
	gtk_dialog_run(GTK_DIALOG(aboutDlg));
	gtk_widget_destroy(aboutDlg);
}


GtkWidget*
create_aboutDlg (void)
{
	
  GtkWidget *aboutDlg;
  GtkWidget *dialog_vbox3;
  GtkWidget *vbox31;
  GtkWidget *alignment4;
  GtkWidget *hbox19;
  GtkWidget *image23;
  GtkWidget *label74;
  GtkWidget *label75;
  GtkWidget *label77;
  GtkWidget *label76;
  GtkWidget *dialog_action_area3;
  GtkWidget *closebutton1;
  gchar     *buf;
	
  aboutDlg = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (aboutDlg), _("About..."));
  gtk_window_set_modal (GTK_WINDOW (aboutDlg), TRUE);
  gtk_window_set_resizable (GTK_WINDOW (aboutDlg), FALSE);

  dialog_vbox3 = GTK_DIALOG (aboutDlg)->vbox;
  gtk_widget_show (dialog_vbox3);

  vbox31 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox31);
  gtk_box_pack_start (GTK_BOX (dialog_vbox3), vbox31, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox31), 11);

  alignment4 = gtk_alignment_new (0.5, 0.5, 0, 1);
  gtk_widget_show (alignment4);
  gtk_box_pack_start (GTK_BOX (vbox31), alignment4, FALSE, FALSE, 0);

  hbox19 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox19);
  gtk_container_add (GTK_CONTAINER (alignment4), hbox19);

  image23 = gtk_image_new_from_pixbuf(gdk_pixbuf_new_from_inline(sizeof(icon_pixbuf), icon_pixbuf, FALSE, NULL));
  gtk_widget_show (image23);
  gtk_box_pack_start (GTK_BOX (hbox19), image23, FALSE, FALSE, 6);

  label74 = gtk_label_new ("<span size=\"xx-large\">" PROGRAM_NAME " " VERSION "</span>");
  gtk_widget_show (label74);
  gtk_box_pack_start (GTK_BOX (hbox19), label74, FALSE, FALSE, 0);
  gtk_widget_set_usize (label74, -2, 70);
  gtk_label_set_use_markup (GTK_LABEL (label74), TRUE);
  gtk_label_set_justify (GTK_LABEL (label74), GTK_JUSTIFY_LEFT);

  buf = g_strdup_printf(_("<span font_family=\"Courier\" foreground=\"#EE5500\" weight=\"bold\" size=\"large\">%s</span><span foreground=\"blue\"><i> is a tool for low-level managing of the parallel port.</i></span>"), PROGRAM_NAME);
  label75 = gtk_label_new (buf);
  g_free(buf);
  gtk_widget_show (label75);
  gtk_box_pack_start (GTK_BOX (vbox31), label75, FALSE, TRUE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label75), TRUE);

  buf = g_strdup_printf(_("\n<b><i>Author:</i></b> %s <i>&lt;%s&gt;</i>\n"
						  "<b><i>Web:</i></b> %s"
						  "\nThis binary was compiled on %s.\n"
  						  "I/O functions: %s\n"),
						  AUTHOR, EMAIL, WEB, __DATE__, strIOFuncType());

  label77 = gtk_label_new (buf);
  g_free(buf);
  gtk_widget_show (label77);
  gtk_box_pack_start (GTK_BOX (vbox31), label77, TRUE, TRUE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label77), TRUE);
  gtk_label_set_justify (GTK_LABEL (label77), GTK_JUSTIFY_LEFT);

  label76 = gtk_label_new ("<small>" COPYRIGHT "</small>");
  gtk_widget_show (label76);
  gtk_box_pack_start (GTK_BOX (vbox31), label76, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label76), TRUE);

  dialog_action_area3 = GTK_DIALOG (aboutDlg)->action_area;
  gtk_widget_show (dialog_action_area3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area3), GTK_BUTTONBOX_END);

  closebutton1 = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (closebutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (aboutDlg), closebutton1, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (closebutton1, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDlg, aboutDlg, "aboutDlg");
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDlg, dialog_vbox3, "dialog_vbox3");
  GLADE_HOOKUP_OBJECT (aboutDlg, vbox31, "vbox31");
  GLADE_HOOKUP_OBJECT (aboutDlg, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (aboutDlg, hbox19, "hbox19");
  GLADE_HOOKUP_OBJECT (aboutDlg, image23, "image23");
  GLADE_HOOKUP_OBJECT (aboutDlg, label74, "label74");
  GLADE_HOOKUP_OBJECT (aboutDlg, label75, "label75");
  GLADE_HOOKUP_OBJECT (aboutDlg, label77, "label77");
  GLADE_HOOKUP_OBJECT (aboutDlg, label76, "label76");
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDlg, dialog_action_area3, "dialog_action_area3");
  GLADE_HOOKUP_OBJECT (aboutDlg, closebutton1, "closebutton1");

  return aboutDlg;
}

