/*  
 *  LPT Manager
 *  Copyright (C) 2002  Giovanni Pardini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdio.h>
#include <unistd.h>
#include <gtk/gtk.h>
#include <glib.h>

#ifdef G_OS_WIN32
#include <windows.h>
#endif

#include "lptmanager.h"
#include "mainWnd.h"
#include "support.h"
#include "options.h"
#include "functions.h"


int
main (int argc, char *argv[])
{

#ifdef ENABLE_NLS
	gchar *locale_dir;
	
	close(STDOUT_FILENO);
	close(STDERR_FILENO);

#ifdef G_OS_WIN32
	locale_dir = g_win32_get_package_installation_subdirectory(GETTEXT_PACKAGE, NULL, "locale");
#else
	locale_dir = g_strdup(PACKAGE_LOCALE_DIR);
#endif

	bindtextdomain (GETTEXT_PACKAGE, locale_dir);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
	
	g_free(locale_dir);
	
#endif /* ENABLE_NLS */
	

	gtk_set_locale ();
	gtk_init (&argc, &argv);
	
	// create main window
	publicVars.mainWnd = create_mainWnd ();
	
	publicVars.timeoutId = -1;
	
	// load options from file
	loadOptions ();
	
	gtk_widget_show (publicVars.mainWnd);
	
	updateWindow ();
	
	gtk_main ();
	
	return 0;
}
