/*  
 *  LPT Manager
 *  Copyright (C) 2002  Giovanni Pardini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef OPTIONS_H
#define OPTIONS_H


#include <glib.h>


// Load options from configuration file (or registry on win32)
void loadOptions(void);
// Save options to configuration file (or registry on win32)
void saveOptions(void);
// This function must be called before terminating the program
void OptionsCleanup(void);


// Functions to access Options

gint     options_set_baseaddr(guint32 baseaddr);
guint32  options_get_baseaddr(void);

void     options_set_timeout(guint32 timeout);
guint32  options_get_timeout(void);

void     options_set_monitor(gboolean status);
gboolean options_get_monitor(void);

void     options_set_modify(gboolean status);
gboolean options_get_modify(void);

void     options_set_showLed(gboolean status);
gboolean options_get_showLed(void);

// check if current baseaddr is a valid address
gboolean options_get_is_valid_addr(void);


// This struct holds all the options.
// Don't access it directly but use above functions.
struct options_t
{
	guint32 baseaddr;
	gboolean is_valid_addr;
	guint32 timeout;
	gboolean monitor;
	gboolean modify;
	gboolean showLed;
} options;


#endif /* Not OPTIONS_H */
