/*  
 *  LPT Manager
 *  Copyright (C) 2002  Giovanni Pardini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include "preferencesDlg.h"

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "preferencesDlg_cb.h"
#include "support.h"
#include "functions.h"
#include "options.h"


void showPreferencesDlg(void)
{
	GtkWidget *preferencesDlg;
	GtkWidget *BaseAddressEntry;
	GtkWidget *TimeoutEntry;
	gboolean   close;
	gchar     *buf;
	
	preferencesDlg = create_preferencesDlg();
	g_object_set_data(G_OBJECT(preferencesDlg), "close", &close);
	gtk_signal_connect(GTK_OBJECT(preferencesDlg), "response",
	                   GTK_SIGNAL_FUNC(on_preferencesDlg_response),
	                   preferencesDlg);
	gtk_window_set_transient_for(GTK_WINDOW(preferencesDlg), GTK_WINDOW(publicVars.mainWnd));
	
	BaseAddressEntry = lookup_widget(preferencesDlg, "BaseAddressEntry");
	TimeoutEntry     = lookup_widget(preferencesDlg, "TimeoutEntry");
	
	buf = g_strdup_printf("0x%X", options_get_baseaddr());
	gtk_entry_set_text(GTK_ENTRY(BaseAddressEntry), buf);
	g_free(buf);
	buf = g_strdup_printf("%d", options_get_timeout());
	gtk_entry_set_text(GTK_ENTRY(TimeoutEntry), buf);
	g_free(buf);
	
	do
		gtk_dialog_run(GTK_DIALOG(preferencesDlg));
	while (!close);
	
	gtk_widget_destroy(preferencesDlg);
}



GtkWidget*
create_preferencesDlg (void)
{
  GtkWidget *preferencesDlg;
  GtkWidget *dialog_vbox2;
  GtkWidget *frame4;
  GtkWidget *table1;
  GtkWidget *label67;
  GtkWidget *BaseAddressEntry;
  GtkWidget *TimeoutEntry;
  GtkWidget *label73;
  GtkWidget *label55;
  GtkWidget *dialog_action_area2;
  GtkWidget *cancelbutton2;
  GtkWidget *applybutton2;
  GtkWidget *okbutton2;

  preferencesDlg = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (preferencesDlg), _("Preferences..."));
  gtk_window_set_modal (GTK_WINDOW (preferencesDlg), TRUE);
  gtk_dialog_set_has_separator (GTK_DIALOG (preferencesDlg), FALSE);

  dialog_vbox2 = GTK_DIALOG (preferencesDlg)->vbox;
  gtk_widget_show (dialog_vbox2);

  frame4 = gtk_frame_new (NULL);
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), frame4, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame4), 5);

  table1 = gtk_table_new (2, 2, FALSE);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (frame4), table1);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 5);
  gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  label67 = gtk_label_new (_("Base address: "));
  gtk_widget_show (label67);
  gtk_table_attach (GTK_TABLE (table1), label67, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label67), GTK_JUSTIFY_LEFT);

  BaseAddressEntry = gtk_entry_new ();
  gtk_widget_show (BaseAddressEntry);
  gtk_table_attach (GTK_TABLE (table1), BaseAddressEntry, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  TimeoutEntry = gtk_entry_new_with_max_length (5);
  gtk_widget_show (TimeoutEntry);
  gtk_table_attach (GTK_TABLE (table1), TimeoutEntry, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (TimeoutEntry, 50, -2);

  label73 = gtk_label_new (_("Timeout (ms): "));
  gtk_widget_show (label73);
  gtk_table_attach (GTK_TABLE (table1), label73, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label73), GTK_JUSTIFY_LEFT);

  label55 = gtk_label_new (_("Preferences"));
  gtk_widget_show (label55);
  gtk_frame_set_label_widget (GTK_FRAME (frame4), label55);
  gtk_label_set_justify (GTK_LABEL (label55), GTK_JUSTIFY_LEFT);

  dialog_action_area2 = GTK_DIALOG (preferencesDlg)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  cancelbutton2 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (preferencesDlg), cancelbutton2, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton2, GTK_CAN_DEFAULT);

  applybutton2 = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (applybutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (preferencesDlg), applybutton2, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (applybutton2, GTK_CAN_DEFAULT);

  okbutton2 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (preferencesDlg), okbutton2, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton2, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (preferencesDlg, preferencesDlg, "preferencesDlg");
  GLADE_HOOKUP_OBJECT_NO_REF (preferencesDlg, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (preferencesDlg, frame4, "frame4");
  GLADE_HOOKUP_OBJECT (preferencesDlg, table1, "table1");
  GLADE_HOOKUP_OBJECT (preferencesDlg, label67, "label67");
  GLADE_HOOKUP_OBJECT (preferencesDlg, BaseAddressEntry, "BaseAddressEntry");
  GLADE_HOOKUP_OBJECT (preferencesDlg, TimeoutEntry, "TimeoutEntry");
  GLADE_HOOKUP_OBJECT (preferencesDlg, label73, "label73");
  GLADE_HOOKUP_OBJECT (preferencesDlg, label55, "label55");
  GLADE_HOOKUP_OBJECT_NO_REF (preferencesDlg, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (preferencesDlg, cancelbutton2, "cancelbutton2");
  GLADE_HOOKUP_OBJECT (preferencesDlg, applybutton2, "applybutton2");
  GLADE_HOOKUP_OBJECT (preferencesDlg, okbutton2, "okbutton2");

  return preferencesDlg;
}
