/*  
 *  LPT Manager
 *  Copyright (C) 2002  Giovanni Pardini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include "preferencesDlg_cb.h"

#include <stdlib.h>
#include <errno.h>

#include "support.h"
#include "functions.h"
#include "options.h"


void
on_preferencesDlg_response             (GtkDialog       *dialog,
                                        gint             arg1,
                                        gpointer         preferencesDlgPtr)
{
	GtkWidget *preferencesDlg   = GTK_WIDGET(preferencesDlgPtr);
	GtkWidget *BaseAddressEntry = lookup_widget(preferencesDlg, "BaseAddressEntry");
	GtkWidget *TimeoutEntry     = lookup_widget(preferencesDlg, "TimeoutEntry");
	gboolean  *closeDialog      = (gboolean*)g_object_get_data(G_OBJECT(preferencesDlg), "close");
	
	*closeDialog = FALSE;
	
	if (arg1 == GTK_RESPONSE_APPLY || arg1 == GTK_RESPONSE_OK)
	{
		gchar *endptr;
		guint32 address, timeout;
		GtkWidget *vbox2 = lookup_widget(publicVars.mainWnd, "vbox2");
		gint ret;
		
		gtk_widget_set_sensitive(vbox2, FALSE);
		errno = 0;
		address = strtol(gtk_entry_get_text(GTK_ENTRY(BaseAddressEntry)), &endptr, 16);

		// number is valid?
		if (errno != 0 || *endptr != '\0')
		{
			// show error message
			showErrorDlg(GTK_WINDOW(preferencesDlg), _("Invalid address!"));
			
			gtk_editable_select_region(GTK_EDITABLE(BaseAddressEntry), 0, -1);
			gtk_widget_grab_focus(BaseAddressEntry);
			return;
		}
		else if ((ret = options_set_baseaddr(address)) != 0)
		{
			/* Show an error message (only under UNIX) */
			
#ifdef G_OS_UNIX
			gchar *buf;
			
			buf = g_strdup_printf(_("Could not get I/O permissions.\n\nDetails: %s\n"), g_strerror(ret));
			showErrorDlg(GTK_WINDOW(preferencesDlg), buf);
			g_free(buf);
#endif
		}
		else
			gtk_widget_set_sensitive(vbox2, TRUE);
		
		
		
		errno = 0;
		timeout = strtol(gtk_entry_get_text(GTK_ENTRY(TimeoutEntry)), &endptr, 10);
		if (errno != 0 || *endptr != '\0' || timeout < 2)
		{
			// show error message
			showErrorDlg(GTK_WINDOW(preferencesDlg), _("Invalid timeout!"));

			gtk_editable_select_region(GTK_EDITABLE(TimeoutEntry), 0, -1);
			gtk_widget_grab_focus(TimeoutEntry);
			return;
		}

		options_set_timeout(timeout);
	}
	
	if (arg1 != GTK_RESPONSE_APPLY)
		*closeDialog = TRUE;	
}
